local G = GLOBAL
local require = G.require
local Ingredient = G.Ingredient
local RECIPETABS = G.RECIPETABS
local STRINGS = G.STRINGS

local is_rog
function IsROG()
	if is_rog == nil then
		is_rog = G.IsDLCEnabled(G.REIGN_OF_GIANTS) and true or false
	end
	return is_rog
end
G.ROG = IsROG()

G.NightmaresTab 	= false
for k,v in ipairs(G.KnownModIndex:GetModsToLoad()) do 
	local Mod = G.KnownModIndex:GetModInfo(v).name
	if Mod == "Nightmares Tab" then
		G.NightmaresTab = true
	end
end

--local languagefile = "scripts/speech/"..GetModConfigData("language").."/sdfstrings.lua"
modimport("scripts/speech/english/sdfstrings.lua")

local oldgetdesc = G.GetDescription
G.GetDescription = function(character, item, modifier)
	local test = oldgetdesc(character, item, modifier)
	local ret = STRINGS.CHARACTERS[character] and STRINGS.CHARACTERS[character].DESCRIBE_GENERIC or STRINGS.CHARACTERS.GENERIC.DESCRIBE_GENERIC
	if test == STRINGS.CHARACTERS.GENERIC.DESCRIBE_GENERIC then
		return ret
	elseif test == STRINGS.CHARACTERS.GENERIC.DESCRIBE_GENERIC..STRINGS.CHARACTERS.GENERIC.ANNOUNCE_CANFIX then
		return ret..STRINGS.CHARACTERS.GENERIC.ANNOUNCE_CANFIX
	elseif test == STRINGS.CHARACTERS.GENERIC.DESCRIBE_GENERIC..STRINGS.CHARACTERS[character].ANNOUNCE_CANFIX then
		return ret..STRINGS.CHARACTERS[character].ANNOUNCE_CANFIX
	else
		return test
	end
end

local oldactionfail = G.GetActionFailString
G.GetActionFailString = function(character, action, reason)
	character = string.upper(character)
	local test = oldactionfail(character, action, reason)
	if test == STRINGS.CHARACTERS.GENERIC.ACTIONFAIL_GENERIC then
		return STRINGS.CHARACTERS[character] and STRINGS.CHARACTERS[character].ACTIONFAIL_GENERIC or STRINGS.CHARACTERS.GENERIC.ACTIONFAIL_GENERIC
	else
		return test
	end
end

G.DanielModCharacters = {"sdf"}
local DanielModPrefabs = {
	"iron_hammer",
	"chalice",
	"short_sword",
	"long_sword",
	"magic_sword",
	"life_bottle",
	"energy_vial",
	"throwing_dagger",
	"iron_axe",
	"cane_stick",
	"gold_armor",
	"victorian_suit",
	"danielhammer_fx"
}

local TempAssets = {
    Asset("SOUNDPACKAGE", "sound/sdf.fev"),
    Asset("SOUND", "sound/sdf.fsb"),	
	Asset("ANIM", "anim/danhealth.zip"),
	Asset("ANIM", "anim/dansanity.zip")
}

local DanielModAssets = {
	{--Inventory Images
		"cane_stick",
		"chalice",
		"chalice_piece",
		"energy_vial",
		"gargoyle",
		"gold_armor",
		"iron_axe",
		"iron_hammer",
		"life_bottle",
		"long_sword",
		"magic_sword",
		"short_sword",
		"throwing_dagger",
		"victorian_suit"
	},
	{--Minimap
		"cane_stick",
		"chalice",
		"energy_vial",
		"gold_armor",
		"iron_axe",
		"iron_hammer",
		"life_bottle",
		"long_sword",
		"magic_sword",
		"short_sword",
		"throwing_dagger",
		"victorian_suit"
	}
}

local filetypes = {
	{"IMAGE", ".tex"},
	{"ATLAS", ".xml"},
	"images/inventoryimages/",
	"images/minimap/"
}
for a,character in pairs(G.DanielModCharacters) do
	table.insert(DanielModPrefabs, character)
	for e = 1,2 do
		table.insert(TempAssets, Asset( filetypes[e][1], "images/saveslot_portraits/"..character..filetypes[e][2] ))
		table.insert(TempAssets, Asset( filetypes[e][1], "images/selectscreen_portraits/"..character..filetypes[e][2] ))
		table.insert(TempAssets, Asset( filetypes[e][1], "images/selectscreen_portraits/"..character.."_silho"..filetypes[e][2] ))
		table.insert(TempAssets, Asset( filetypes[e][1], "bigportraits/"..character..filetypes[e][2] ))
		table.insert(TempAssets, Asset( filetypes[e][1], "images/minimap/"..character..filetypes[e][2] ))
		--table.insert(TempAssets, Asset( filetypes[e][1], "images/avatars/avatar_"..character..filetypes[e][2] ))
		--table.insert(TempAssets, Asset( filetypes[e][1], "images/avatars/avatar_ghost_"..character..filetypes[e][2] ))
	end
end
for i = 1,2 do
	for k,v in pairs(DanielModAssets[i]) do
		for o = 1,2 do
			table.insert(TempAssets, Asset( filetypes[o][1], filetypes[(i + 2)]..v..filetypes[o][2] ))
		end
	end
end

PrefabFiles = DanielModPrefabs
Assets = TempAssets

for k,v in pairs(DanielModAssets[2]) do
	AddMinimapAtlas("images/minimap/"..v..".xml")
end

local voicenames = { "death_voice", "hurt", "talk_LP", "emote", "ghost_LP", --[["yawn"]] }
for a,character in pairs(G.DanielModCharacters) do
	AddMinimapAtlas("images/minimap/"..character..".xml")
	for key,sound in pairs(voicenames) do
		RemapSoundEvent( "dontstarve/characters/"..character.."/"..sound, "sdf/characters/"..character.."/"..sound)
	end
	table.insert(G.CHARACTER_GENDERS.MALE, character)
	AddModCharacter(character)
end
RemapSoundEvent( "dontstarve/characters/sdf/yawn", "dontstarve/characters/willow/yawn") --because we couldn't recreate the old sounds.

modimport("scripts/sirdaniel_actions.lua")
modimport("scripts/sirdaniel_crafting.lua")
modimport("scripts/stategraphs/sirdaniel_stategraphs.lua")
modimport("scripts/widgets/sirdaniel_statusdisplays.lua")
modimport("scripts/postinits/sdfitempostinits.lua")
modimport("scripts/postinits/sdfcustommaxwellintros.lua")

local daniel_ground_fx =
    {
        name = "daniel_ground_fx",
        bank = "daniel_ground_fx",
        build = "daniel_ground_fx",
        anim = "idle",
    }
 
G.table.insert(G.require("fx"), daniel_ground_fx)